Span

Type Alias Span 

pub type Span<'a> = LocatedSpan<&'a str, &'a QueryContainer>;
Type used to track the current fragment being parsed and its location in the original input.

Aliased Type

pub struct Span<'a> {
    pub extra: &'a QueryContainer,
    /* private fields */
}

Fields

extra: &'a QueryContainer

Extra information that can be embedded by the user. Example: the parsed file name