pub type Span<'a> = LocatedSpan<&'a str, &'a QueryContainer>;Expand description
Type used to track the current fragment being parsed and its location in the original input.
Aliased Type
pub struct Span<'a> {
pub extra: &'a QueryContainer,
/* private fields */
}Fields
extra: &'a QueryContainerExtra information that can be embedded by the user. Example: the parsed file name